package com.manalejandro.arjion.controllers;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;

import com.manalejandro.arjion.model.Archivo;
import com.manalejandro.arjion.vo.DocumentoVO;

import org.apache.tika.config.TikaConfig;
import org.apache.tika.exception.TikaException;
import org.apache.tika.io.TikaInputStream;
import org.apache.tika.language.LanguageIdentifier;
import org.apache.tika.metadata.Metadata;
import org.apache.tika.parser.AutoDetectParser;
import org.apache.tika.parser.ParseContext;
import org.apache.tika.sax.BodyContentHandler;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

@Controller
public class MainController {

    @Value("${arjion.uploadpath}")
    private String uploadpath;

    @RequestMapping(path = "/")
    public String indexPage(final Model model) {
        DocumentoVO documentoVO = new DocumentoVO();
        model.addAttribute("documentoVO", documentoVO);
        return "index";
    }

    @GetMapping(path = "/upload")
    public String upload() {
        return "redirect:/";
    }

    @PostMapping(path = "/upload")
    public String uploadPage(final Model model, @RequestParam("archivos") MultipartFile[] archivos)
            throws IOException, TikaException, SAXException {
        DocumentoVO documentoVO = new DocumentoVO();
        documentoVO.setArchivos(new ArrayList<Archivo>());
        TikaConfig tikaConfig = TikaConfig.getDefaultConfig();
        for (int i = 0; i < archivos.length; i++) {
            byte[] bytes = archivos[i].getBytes();
            Path path = Paths.get(uploadpath + archivos[i].getOriginalFilename());
            Files.write(path, bytes);
            Metadata metadata = new Metadata();
            AutoDetectParser parser = new AutoDetectParser(tikaConfig);
            ContentHandler handler = new BodyContentHandler(-1);
            TikaInputStream stream = TikaInputStream.get(bytes);
            parser.parse(stream, handler, metadata, new ParseContext());
            LanguageIdentifier identifier = new LanguageIdentifier(handler.toString());
            documentoVO.getArchivos().add(new Archivo(archivos[i].getOriginalFilename(), String.valueOf(archivos[i].getSize()),
                    metadata.toString(), handler.toString(), identifier.getLanguage()));
        }
        model.addAttribute("documentoVO", documentoVO);
        return "index";
    }
}
